@@ -1,79 +1,78 @@
 #include <time.h>
-void writeHeader() {
-time_t timeId;
-timeId = time(NULL);
-sAppend(&sbOut, "#define _getRxSolve_ _getRxSolve_%ld\n", timeId);
-sAppend(&sbOut, "#define simeps simeps%ld\n", timeId);
-sAppend(&sbOut, "#define simeta simeta%ld\n", timeId);
-sAppend(&sbOut, "#define _solveData _solveData%ld\n", timeId);
-sAppend(&sbOut, "#define _assign_ptr _assign_ptr%ld\n", timeId);
-sAppend(&sbOut, "#define _rxRmModelLib _rxRmModelLib%ld\n", timeId);
-sAppend(&sbOut, "#define _rxGetModelLib _rxGetModelLib%ld\n", timeId);
-sAppend(&sbOut, "#define _old_c _old_c%ld\n", timeId);
-sAppend(&sbOut, "#define _ptrid _ptrid%ld\n", timeId);
-sAppend(&sbOut, "#define _rxIsCurrentC _rxIsCurrentC%ld\n", timeId);
-sAppend(&sbOut, "#define _sumPS _sumPS%ld\n", timeId);
-sAppend(&sbOut, "#define _prodPS _prodPS%ld\n", timeId);
-sAppend(&sbOut, "#define _prodType _prodType%ld\n", timeId);
-sAppend(&sbOut, "#define _sumType _sumType%ld\n", timeId);
-sAppend(&sbOut, "#define _update_par_ptr _update_par_ptr%ld\n", timeId);
-sAppend(&sbOut, "#define _getParCov _getParCov%ld\n", timeId);
-sAppend(&sbOut, "#define linCmtA linCmtA%ld\n", timeId);
-sAppend(&sbOut, "#define linCmtC linCmtC%ld\n", timeId);
-sAppend(&sbOut, "#define linCmtB linCmtB%ld\n", timeId);
-sAppend(&sbOut, "#define _RxODE_rxAssignPtr _RxODE_rxAssignPtr%ld\n", timeId);
-sAppend(&sbOut, "#define _rxQr _rxQr%ld\n", timeId);
-sAppend(&sbOut, "#define phi phi%ld\n", timeId);
-sAppend(&sbOut, "#define logit logit%ld\n", timeId);
-sAppend(&sbOut, "#define expit expit%ld\n", timeId);
-sAppend(&sbOut, "#define gammap gammap%ld\n", timeId);
-sAppend(&sbOut, "#define gammaq gammaq%ld\n", timeId);
-sAppend(&sbOut, "#define lowergamma lowergamma%ld\n", timeId);
-sAppend(&sbOut, "#define uppergamma uppergamma%ld\n", timeId);
-sAppend(&sbOut, "#define gammapInv gammapInv%ld\n", timeId);
-sAppend(&sbOut, "#define gammapDer gammapDer%ld\n", timeId);
-sAppend(&sbOut, "#define gammapInva gammapInva%ld\n", timeId);
-sAppend(&sbOut, "#define gammaqInv gammaqInv%ld\n", timeId);
-sAppend(&sbOut, "#define gammaqInva gammaqInva%ld\n", timeId);
-sAppend(&sbOut, "#define rxnorm rxnorm%ld\n", timeId);
-sAppend(&sbOut, "#define rxnormV rxnormV%ld\n", timeId);
-sAppend(&sbOut, "#define rxbinom rxbinom%ld\n", timeId);
-sAppend(&sbOut, "#define rxcauchy rxcauchy%ld\n", timeId);
-sAppend(&sbOut, "#define rxchisq rxchisq%ld\n", timeId);
-sAppend(&sbOut, "#define rxexp rxexp%ld\n", timeId);
-sAppend(&sbOut, "#define rxf rxf%ld\n", timeId);
-sAppend(&sbOut, "#define rxgeom rxgeom%ld\n", timeId);
-sAppend(&sbOut, "#define rxgamma rxgamma%ld\n", timeId);
-sAppend(&sbOut, "#define rxbeta rxbeta%ld\n", timeId);
-sAppend(&sbOut, "#define rxpois rxpois%ld\n", timeId);
-sAppend(&sbOut, "#define rxt_ rxt_%ld\n", timeId);
-sAppend(&sbOut, "#define rxunif rxunif%ld\n", timeId);
-sAppend(&sbOut, "#define rxweibull rxweibull%ld\n", timeId);
-sAppend(&sbOut, "#define rinorm rinorm%ld\n", timeId);
-sAppend(&sbOut, "#define rinormV rinormV%ld\n", timeId);
-sAppend(&sbOut, "#define ribinom ribinom%ld\n", timeId);
-sAppend(&sbOut, "#define ricauchy ricauchy%ld\n", timeId);
-sAppend(&sbOut, "#define richisq richisq%ld\n", timeId);
-sAppend(&sbOut, "#define riexp riexp%ld\n", timeId);
-sAppend(&sbOut, "#define rif rif%ld\n", timeId);
-sAppend(&sbOut, "#define rigeom rigeom%ld\n", timeId);
-sAppend(&sbOut, "#define rigamma rigamma%ld\n", timeId);
-sAppend(&sbOut, "#define ribeta ribeta%ld\n", timeId);
-sAppend(&sbOut, "#define ripois ripois%ld\n", timeId);
-sAppend(&sbOut, "#define rit_ rit_%ld\n", timeId);
-sAppend(&sbOut, "#define riunif riunif%ld\n", timeId);
-sAppend(&sbOut, "#define riweibull riweibull%ld\n", timeId);
-sAppend(&sbOut, "#define _compareFactorVal _compareFactorVal%ld\n", timeId);
-sAppend(&sbOut, "#define _sum _sum%ld\n", timeId);
-sAppend(&sbOut, "#define _sign _sign%ld\n", timeId);
-sAppend(&sbOut, "#define _prod _prod%ld\n", timeId);
-sAppend(&sbOut, "#define _max _max%ld\n", timeId);
-sAppend(&sbOut, "#define _min _min%ld\n", timeId);
-sAppend(&sbOut, "#define _transit4P _transit4P%ld\n", timeId);
-sAppend(&sbOut, "#define _transit3P _transit3P%ld\n", timeId);
-sAppend(&sbOut, "#define _assignFuns0 _assignFuns0%ld\n", timeId);
-sAppend(&sbOut, "#define _assignFuns _assignFuns%ld\n", timeId);
-sAppend(&sbOut, "#define _getRxSolve_ _getRxSolve_%ld\n", timeId);
+#include <stdlib.h>
+void writeHeader(const char *md5, const char *extra) {
+unsigned long int timeId=0;
+sAppend(&sbOut, "#define _getRxSolve_ _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define simeps _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define simeta _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _solveData _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _assign_ptr _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _rxRmModelLib _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _rxGetModelLib _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _old_c _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _ptrid _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _rxIsCurrentC _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _sumPS _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _prodPS _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _prodType _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _sumType _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _update_par_ptr _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _getParCov _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define linCmtA _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define linCmtC _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define linCmtB _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _RxODE_rxAssignPtr _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _rxQr _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define phi _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define logit _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define expit _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define gammap _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define gammaq _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define lowergamma _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define uppergamma _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define gammapInv _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define gammapDer _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define gammapInva _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define gammaqInv _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define gammaqInva _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxnorm _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxnormV _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxbinom _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxcauchy _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxchisq _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxexp _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxf _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxgeom _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxgamma _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxbeta _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxpois _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxt_ _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxunif _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rxweibull _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rinorm _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rinormV _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define ribinom _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define ricauchy _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define richisq _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define riexp _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rif _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rigeom _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rigamma _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define ribeta _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define ripois _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define rit_ _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define riunif _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define riweibull _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _compareFactorVal _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _sum _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _sign _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _prod _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _max _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _min _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _transit4P _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _transit3P _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _assignFuns0 _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _assignFuns _rx%s%s%ld\n", extra, md5, timeId++);
 }
 void writeBody() {
 sAppendN(&sbOut, "_getRxSolve_t _getRxSolve_;\n", 28);
@@ -288,3 +287,76 @@ sAppendN(&sbOut, "    _assignFuns0();\n", 20);
 sAppendN(&sbOut, "  }\n", 4);
 sAppendN(&sbOut, "}\n", 2);
 }
+void writeFooter() {
+sAppendN(&sbOut, "#undef _getRxSolve_\n", 20);
+sAppendN(&sbOut, "#undef simeps\n", 14);
+sAppendN(&sbOut, "#undef simeta\n", 14);
+sAppendN(&sbOut, "#undef _solveData\n", 18);
+sAppendN(&sbOut, "#undef _assign_ptr\n", 19);
+sAppendN(&sbOut, "#undef _rxRmModelLib\n", 21);
+sAppendN(&sbOut, "#undef _rxGetModelLib\n", 22);
+sAppendN(&sbOut, "#undef _old_c\n", 14);
+sAppendN(&sbOut, "#undef _ptrid\n", 14);
+sAppendN(&sbOut, "#undef _rxIsCurrentC\n", 21);
+sAppendN(&sbOut, "#undef _sumPS\n", 14);
+sAppendN(&sbOut, "#undef _prodPS\n", 15);
+sAppendN(&sbOut, "#undef _prodType\n", 17);
+sAppendN(&sbOut, "#undef _sumType\n", 16);
+sAppendN(&sbOut, "#undef _update_par_ptr\n", 23);
+sAppendN(&sbOut, "#undef _getParCov\n", 18);
+sAppendN(&sbOut, "#undef linCmtA\n", 15);
+sAppendN(&sbOut, "#undef linCmtC\n", 15);
+sAppendN(&sbOut, "#undef linCmtB\n", 15);
+sAppendN(&sbOut, "#undef _RxODE_rxAssignPtr\n", 26);
+sAppendN(&sbOut, "#undef _rxQr\n", 13);
+sAppendN(&sbOut, "#undef phi\n", 11);
+sAppendN(&sbOut, "#undef logit\n", 13);
+sAppendN(&sbOut, "#undef expit\n", 13);
+sAppendN(&sbOut, "#undef gammap\n", 14);
+sAppendN(&sbOut, "#undef gammaq\n", 14);
+sAppendN(&sbOut, "#undef lowergamma\n", 18);
+sAppendN(&sbOut, "#undef uppergamma\n", 18);
+sAppendN(&sbOut, "#undef gammapInv\n", 17);
+sAppendN(&sbOut, "#undef gammapDer\n", 17);
+sAppendN(&sbOut, "#undef gammapInva\n", 18);
+sAppendN(&sbOut, "#undef gammaqInv\n", 17);
+sAppendN(&sbOut, "#undef gammaqInva\n", 18);
+sAppendN(&sbOut, "#undef rxnorm\n", 14);
+sAppendN(&sbOut, "#undef rxnormV\n", 15);
+sAppendN(&sbOut, "#undef rxbinom\n", 15);
+sAppendN(&sbOut, "#undef rxcauchy\n", 16);
+sAppendN(&sbOut, "#undef rxchisq\n", 15);
+sAppendN(&sbOut, "#undef rxexp\n", 13);
+sAppendN(&sbOut, "#undef rxf\n", 11);
+sAppendN(&sbOut, "#undef rxgeom\n", 14);
+sAppendN(&sbOut, "#undef rxgamma\n", 15);
+sAppendN(&sbOut, "#undef rxbeta\n", 14);
+sAppendN(&sbOut, "#undef rxpois\n", 14);
+sAppendN(&sbOut, "#undef rxt_\n", 12);
+sAppendN(&sbOut, "#undef rxunif\n", 14);
+sAppendN(&sbOut, "#undef rxweibull\n", 17);
+sAppendN(&sbOut, "#undef rinorm\n", 14);
+sAppendN(&sbOut, "#undef rinormV\n", 15);
+sAppendN(&sbOut, "#undef ribinom\n", 15);
+sAppendN(&sbOut, "#undef ricauchy\n", 16);
+sAppendN(&sbOut, "#undef richisq\n", 15);
+sAppendN(&sbOut, "#undef riexp\n", 13);
+sAppendN(&sbOut, "#undef rif\n", 11);
+sAppendN(&sbOut, "#undef rigeom\n", 14);
+sAppendN(&sbOut, "#undef rigamma\n", 15);
+sAppendN(&sbOut, "#undef ribeta\n", 14);
+sAppendN(&sbOut, "#undef ripois\n", 14);
+sAppendN(&sbOut, "#undef rit_\n", 12);
+sAppendN(&sbOut, "#undef riunif\n", 14);
+sAppendN(&sbOut, "#undef riweibull\n", 17);
+sAppendN(&sbOut, "#undef _compareFactorVal\n", 25);
+sAppendN(&sbOut, "#undef _sum\n", 12);
+sAppendN(&sbOut, "#undef _sign\n", 13);
+sAppendN(&sbOut, "#undef _prod\n", 13);
+sAppendN(&sbOut, "#undef _max\n", 12);
+sAppendN(&sbOut, "#undef _min\n", 12);
+sAppendN(&sbOut, "#undef _transit4P\n", 18);
+sAppendN(&sbOut, "#undef _transit3P\n", 18);
+sAppendN(&sbOut, "#undef _assignFuns0\n", 20);
+sAppendN(&sbOut, "#undef _assignFuns\n", 19);
+}
